/*!
 * Copyright Adaptavist 2025 (c) All rights reserved
 */
export interface S3CopyObject {
    /**
     * The Base64 encoded, 32-bit CRC-32 checksum of the object. This checksum is only present if the object was uploaded with the object.
     */
    ChecksumCRC32?: string;
    /**
     * The Base64 encoded, 32-bit CRC-32C checksum of the object. This will only be present if the object was uploaded with the object.
     */
    ChecksumCRC32C?: string;
    /**
     * The Base64 encoded, 64-bit CRC-64NVME checksum of the object. This checksum is present if the object being copied was uploaded with the CRC-64NVME checksum algorithm, or if the object was uploaded without a checksum (and Amazon S3 added the default checksum, CRC-64NVME, to the uploaded object).
     */
    ChecksumCRC64NVME?: string;
    /**
     * The Base64 encoded, 160-bit SHA-1 digest of the object. This will only be present if the object was uploaded with the object.
     */
    ChecksumSHA1?: string;
    /**
     * The Base64 encoded, 256-bit SHA-256 digest of the object. This will only be present if the object was uploaded with the object.
     */
    ChecksumSHA256?: string;
    /**
     * The checksum type that is used to calculate the object’s checksum value.
     */
    ChecksumType?: 'COMPOSITE' | 'FULL_OBJECT';
    /**
     * Returns the ETag of the new object. The ETag reflects only changes to the contents of an object, not its metadata.
     */
    ETag?: string;
    /**
     * Creation date of the object.
     */
    LastModified?: string;
}
//# sourceMappingURL=S3CopyObject.d.ts.map