/*!
 * Copyright Adaptavist 2025 (c) All rights reserved
 */
import { Owner } from './Owner';
import { RestoreStatus } from './RestoreStatus';
export interface S3Object {
    /**
     * The algorithm that was used to create a checksum of the object.
     */
    ChecksumAlgorithm?: ('CRC32' | 'CRC32C' | 'SHA1' | 'SHA256' | 'CRC64NVME')[];
    /**
     * The checksum type that is used to calculate the object’s checksum value.
     */
    ChecksumType?: 'COMPOSITE' | 'FULL_OBJECT';
    /**
     * The entity tag is a hash of the object. The ETag reflects changes only to the contents of an object, not its metadata. The ETag may or may not be an MD5 digest of the object data. Whether or not it is depends on how the object was created and how it is encrypted as described below:

    ** Objects created by the PUT Object, POST Object, or Copy operation, or through the AWS Management Console, and are encrypted by SSE-S3 or plaintext, have ETags that are an MD5 digest of their object data.

    ** Objects created by the PUT Object, POST Object, or Copy operation, or through the AWS Management Console, and are encrypted by SSE-C or SSE-KMS, have ETags that are not an MD5 digest of their object data.

    ** If an object is created by either the Multipart Upload or Part Copy operation, the ETag is not an MD5 digest, regardless of the method of encryption. If an object is larger than 16 MB, the AWS Management Console will upload or copy that object as a Multipart Upload, and therefore the ETag will not be an MD5 digest.
     */
    ETag?: string;
    /**
     * The name that you assign to an object. You use the object key to retrieve the object.
     */
    Key?: string;
    /**
     * Creation date of the object.
     */
    LastModified?: string;
    /**
     * The owner of the object
     */
    Owner?: Owner;
    /**
     * Specifies the restoration status of an object. Objects in certain storage classes must be restored before they can be retrieved.
     */
    RestoreStatus?: RestoreStatus;
    /**
     * Size in bytes of the object
     */
    Size?: number;
    /**
     * The class of storage used to store the object.
     */
    StorageClass?: 'STANDARD' | 'REDUCED_REDUNDANCY' | 'GLACIER' | 'STANDARD_IA' | 'ONEZONE_IA' | 'INTELLIGENT_TIERING' | 'DEEP_ARCHIVE' | 'OUTPOSTS' | 'GLACIER_IR' | 'SNOW' | 'EXPRESS_ONEZONE';
}
//# sourceMappingURL=S3Object.d.ts.map