/*!
 * Copyright Adaptavist 2025 (c) All rights reserved
 */
import { Owner } from './Owner';
import { RestoreStatus } from './RestoreStatus';
export interface S3ObjectVersion {
    /**
     * The algorithm that was used to create a checksum of the object.
     */
    ChecksumAlgorithm?: ('CRC32' | 'CRC32C' | 'SHA1' | 'SHA256' | 'CRC64NVME')[];
    /**
     * The checksum type that is used to calculate the object’s checksum value.
     */
    ChecksumType?: 'COMPOSITE' | 'FULL_OBJECT';
    /**
     * The entity tag is an MD5 hash of that version of the object.
     */
    ETag?: string;
    /**
     * Specifies whether the object is (true) or is not (false) the latest version of an object.
     */
    IsLatest?: boolean;
    /**
     * The object key.
     */
    Key?: string;
    /**
     * Date and time when the object was last modified.
     */
    LastModified?: string;
    /**
     * Specifies the owner of the object.
     */
    Owner?: Owner;
    /**
     * Specifies the restoration status of an object. Objects in certain storage classes must be restored before they can be retrieved.
     */
    RestoreStatus?: RestoreStatus;
    /**
     * Size in bytes of the object.
     */
    Size?: number;
    /**
     * The class of storage used to store the object.
     */
    StorageClass?: 'STANDARD';
    /**
     * Version ID of an object.
     */
    VersionId?: string;
}
//# sourceMappingURL=S3ObjectVersion.d.ts.map