/*!
 * Copyright Adaptavist 2025 (c) All rights reserved
 */
import { CommonPrefix } from './CommonPrefix';
import { DeleteMarkerEntry } from './DeleteMarkerEntry';
import { S3ObjectVersion } from './S3ObjectVersion';
export interface S3ObjectVersions {
    /**
     * All of the keys rolled up into a common prefix count as a single return when calculating the number of returns.
     */
    CommonPrefixes?: CommonPrefix[];
    /**
     * Container for an object that is a delete marker.
     */
    DeleteMarker?: DeleteMarkerEntry[];
    /**
     * The delimiter grouping the included keys. A delimiter is a character that you specify to group keys. All keys that contain the same string between the prefix and the first occurrence of the delimiter are grouped under a single result element in CommonPrefixes. These groups are counted as one result against the max-keys limitation. These keys are not returned elsewhere in the response.
     */
    Delimiter?: string;
    /**
     * Encoding type used by Amazon S3 to encode object key names in the XML response.

    If you specify the encoding-type request parameter, Amazon S3 includes this element in the response, and returns encoded key name values in the following response elements:

    KeyMarker, NextKeyMarker, Prefix, Key, and Delimiter.
     */
    EncodingType?: 'url';
    /**
     * A flag that indicates whether Amazon S3 returned all of the results that satisfied the search criteria. If your results were truncated, you can make a follow-up paginated request by using the NextKeyMarker and NextVersionIdMarker response parameters as a starting place in another request to return the rest of the results.
     */
    IsTruncated?: boolean;
    /**
     * Marks the last key returned in a truncated response.
     */
    KeyMarker?: string;
    /**
     * Specifies the maximum number of objects to return.
     */
    MaxKeys?: number;
    /**
     * The bucket name.
     */
    Name?: string;
    /**
     * When the number of responses exceeds the value of MaxKeys, NextKeyMarker specifies the first key not returned that satisfies the search criteria. Use this value for the key-marker request parameter in a subsequent request.
     */
    NextKeyMarker?: string;
    /**
     * When the number of responses exceeds the value of MaxKeys, NextVersionIdMarker specifies the first object version not returned that satisfies the search criteria. Use this value for the version-id-marker request parameter in a subsequent request.
     */
    NextVersionIdMarker?: string;
    /**
     * Selects objects that start with the value supplied by this parameter.
     */
    Prefix?: string;
    /**
     * Container for version information.
     */
    Version?: S3ObjectVersion[];
    /**
     * Marks the last version of the key returned in a truncated response.
     */
    VersionIdMarker?: string;
}
//# sourceMappingURL=S3ObjectVersions.d.ts.map