/*!
 * Copyright Adaptavist 2025 (c) All rights reserved
 */
import { CommonPrefix } from './CommonPrefix';
import { S3Object } from './S3Object';
export interface S3Objects {
    /**
     * All of the keys (up to 1,000) that share the same prefix are grouped together. When counting the total numbers of returns by this API operation, this group of keys is considered as one item.

    A response can contain CommonPrefixes only if you specify a delimiter.

    CommonPrefixes contains all (if there are any) keys between Prefix and the next occurrence of the string specified by a delimiter.

    CommonPrefixes lists keys that act like subdirectories in the directory specified by Prefix.

    For example, if the prefix is notes/ and the delimiter is a slash (/) as in notes/summer/july, the common prefix is notes/summer/. All of the keys that roll up into a common prefix count as a single return when calculating the number of returns.
     */
    CommonPrefixes?: CommonPrefix[];
    /**
     * Metadata about each object returned.
     */
    Contents?: S3Object[];
    /**
     * If ContinuationToken was sent with the request, it is included in the response. You can use the returned ContinuationToken for pagination of the list response. You can use this ContinuationToken for pagination of the list results.
     */
    ContinuationToken?: string;
    /**
     * Causes keys that contain the same string between the prefix and the first occurrence of the delimiter to be rolled up into a single result element in the CommonPrefixes collection. These rolled-up keys are not returned elsewhere in the response. Each rolled-up result counts as only one return against the MaxKeys value.
     */
    Delimiter?: string;
    /**
     * Encoding type used by Amazon S3 to encode object key names in the XML response.

    If you specify the encoding-type request parameter, Amazon S3 includes this element in the response, and returns encoded key name values in the following response elements:

    Delimiter, Prefix, Key, and StartAfter.
     */
    EncodingType?: 'url';
    /**
     * Set to false if all of the results were returned. Set to true if more keys are available to return. If the number of results exceeds that specified by MaxKeys, all of the results might not be returned.
     */
    IsTruncated?: boolean;
    /**
     * KeyCount is the number of keys returned with this request. KeyCount will always be less than or equal to the MaxKeys field. For example, if you ask for 50 keys, your result will include 50 keys or fewer.
     */
    KeyCount?: number;
    /**
     * Sets the maximum number of keys returned in the response. By default, the action returns up to 1,000 key names. The response might contain fewer keys but will never contain more.
     */
    MaxKeys?: number;
    /**
     * The bucket name.
     */
    Name?: string;
    /**
     * NextContinuationToken is sent when isTruncated is true, which means there are more keys in the bucket that can be listed. The next list requests to Amazon S3 can be continued with this NextContinuationToken. NextContinuationToken is obfuscated and is not a real key
     */
    NextContinuationToken?: string;
    /**
     * Keys that begin with the indicated prefix.
     */
    Prefix?: string;
    /**
     * If StartAfter was sent with the request, it is included in the response.
     */
    StartAfter?: string;
}
//# sourceMappingURL=S3Objects.d.ts.map